=================
Converting Models
=================

pymad8 provdies converters to allow BDSIM models to prepared from optical
descriptions in MAD8.


Mad8Twiss2Gmad
--------------

TBC

Mad8Saveline2Gmad
-----------------

TBC
